Skip to contents

Aggregates long-form SUT data onto product and industry mappings and builds the country-year matrix bundle used by `compute_sube()`.

Usage

build_matrices(sut_data, cpa_map, ind_map, final_demand_var = "FU_bas")

Arguments

sut_data

Long-form SUT data.

cpa_map

Product correspondence table.

ind_map

Industry correspondence table.

final_demand_var

Long-form variable used for final demand.

Value

A `sube_matrices` object containing aggregated long-form data, final demand, and a list of country-year `S` and `U` matrices.